#
# spec file for package iouyap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iouyap
Version:        0.97
Release:        bp160.1.7
Summary:        Bridge IOU to TAP, UDP and Ethernet
License:        GPL-3.0-or-later
Group:          System/Emulators/Other
URL:            https://github.com/GNS3/iouyap
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  glibc-devel
Requires(pre):  shadow
Provides:       group(iouyap)
%if 0%{?suse_version}
Requires(pre):  permissions
%endif

%description
Bridge IOU to TAP, UDP and Ethernet, mainly used by gns3server

In order to use iouyap as non-root user, the user needs to be member of the iouyap group!

%prep
%setup -q

%build
bison --yacc -dv netmap_parse.y
flex netmap_scan.l
gcc -I -Wall -fPIE %optflags -fcommon *.c iniparser/*.c -o %{name} -lpthread -pie

%install
%__mkdir_p %{buildroot}/%{_libexecdir}
%__mkdir_p %{buildroot}/%{_bindir}
%__mv %{name} %{buildroot}/%{_libexecdir}
ln -sf %{_libexecdir}/%{name} %{buildroot}/%{_bindir}/%{name}

%pre
%{_sbindir}/groupadd -r iouyap 2> /dev/null || :

%if 0%{?suse_version}
%post
%set_permissions %{_libexecdir}/%{name}

%verifyscript
%verify_permissions -e %{_libexecdir}/%{name}
%endif

%files
%license LICENSE
%doc README.rst
%verify(not caps) %attr(0750,root,iouyap) %{_libexecdir}/%{name}
%{_bindir}/%{name}

%changelog
* Mon Feb 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Provide group(iouyap): the group is generated in the pre script.
  Advertise the capability in order tix installation of package
  built using RPM 4.19.
* Tue Jun  9 2020 Martin Hauke <mardnh@gmx.de>
- Set CFLAGS+=-fcommon to workaround gcc10 errors (boo#1160244)
- Run spec-cleaner
* Sat Mar 12 2016 andrea@opensuse.org
- new upstream version 0.97
  * Fix crash during capture
  * Enbed iniparser
- removed all patches now in upstream code:
  * iouyap-0.95_buff_overflow.patch
  * iouyap-0.95_log_error.patch
  * iouyap-0.95_fix_packet_mem_corruption.patch
  * iouyap-0.95_fix_ownership.patch
* Tue Jan 13 2015 andrea@opensuse.org
- added iouyap-0.95_fix_ownership.patch from upstream code
* Fri Dec 12 2014 andrea@opensuse.org
- added -I flag when compiling
* Thu Dec 11 2014 andrea@opensuse.org
- Fixed package description
- made rpmlint happy by using -fPIE and -pie flags to make the code
  position independent
* Wed Dec  3 2014 andrea@opensuse.org
- made sure we don't break Fedora
* Wed Dec  3 2014 meissner@suse.com
- hook up to permission framework. bnc#904060
* Wed Dec  3 2014 andrea@opensuse.org
- added pre script to add user iouyap and fix security audit boo# 904060
- removed post script and pre-req for post scripts
* Wed Dec  3 2014 andrea@opensuse.org
- moved iouyap from /usr/bin into /usr/lib (libexecdir)
- set iouyap permissions to 0750 and root,iouyap
* Wed Dec  3 2014 andrea@opensuse.org
- added iouyap-0.95_buff_overflow.patch to fix buffer overflows
- added iouyap-0.95_log_error.patch to fix format specifiers in log_error calls
- added iouyap-0.95_fix_packet_mem_corruption.patch to fix mem corruption issues
* Mon Nov 24 2014 andrea@opensuse.org
- removed setcap in post scripts
* Thu Jul 10 2014 andrea@opensuse.org
- fixed packet capture on 64 bits system
- removed IFF_MULTI_QUEUE patch now in upstream code
* Sun Jun 15 2014 andrea@opensuse.org
- added iouyap-0.1-IFF_MULTI_QUEUE.patch to allow build on suse <= 12.3
* Sat Jun  7 2014 andrea@opensuse.org
- added Packet capture support.
* Thu May 15 2014 andrea@opensuse.org
- new package
